@@ -7,12 +7,9 @@ class Factory(ClientFactory):
         super().__init__()
         self.client = kwargs['client']
         self.numberOfMessagesToSendPerSecond = self.client.numberOfMessagesToSendPerSecond
-    def buildProtocol(self, addr):
-        protocol = super().buildProtocol(addr)
-        return protocol
     def connected(self, protocol):
         self.client._connected(protocol)
     def disconnected(self, reason):
         self.client._disconnected(reason)
     def received(self, message):
-        self.client._received(message)
\ No newline at end of file
+        self.client._received(message)
